$direction-up: "\f058";
$direction-up-right: "\f057";
$direction-right: "\f04d";
$direction-down-right: "\f088";
$direction-down: "\f044";
$direction-down-left: "\f043";
$direction-left: "\f048";
$direction-up-left: "\f087";
