@media all {
    .aa-timezones .form-inline .form-group {
        margin-bottom: 8px;
        margin-bottom: 0.5rem;
    }

    .aa-timezones .timezone-panel-section {
        display: block;
    }

    .aa-timezones .timezone-panel-section-time {
        font-size: 140%;
    }

    .aa-timezones .timezone-panel-section-utc-offset {
        font-size: 85%;
    }

    .aa-timezones .aa-timezones-time-until {
        font-weight: 600;
        font-size: 125%;
    }
}
