@import "weather-icons-core.less";
@import "icon-variables/variables-wind-names.less";
@import "icon-classes/classes-wind.less";
@import "icon-classes/classes-wind-degrees.less";
@import "icon-classes/classes-wind-aliases.less";
